@@ -122,9 +122,6 @@ struct _GeditPreferencesDialogPrivate
 
 	/* Plugins manager */
 	GtkWidget	*plugin_manager_place_holder;
-
-	/* Style Scheme editor dialog */
-	GtkWidget	*style_scheme_dialog;
 };
 
 
@@ -907,7 +904,7 @@ setup_plugins_page (GeditPreferencesDialog *dlg)
 
 	gedit_debug (DEBUG_PREFS);
 
-	page_content = peas_gtk_plugin_manager_new ();
+	page_content = peas_gtk_plugin_manager_new (NULL);
 	g_return_if_fail (page_content != NULL);
 
 	gtk_box_pack_start (GTK_BOX (dlg->priv->plugin_manager_place_holder),
@@ -1049,4 +1046,4 @@ gedit_show_preferences_dialog (GeditWindow *parent)
 	gtk_window_present (GTK_WINDOW (preferences_dialog));
 }
 
-/* ex:ts=8:noet: */
+/* ex:set ts=8 noet: */
