@@ -20,6 +20,10 @@
  * Boston, MA  02110-1301  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gedit-view-frame.h"
 #include "gedit-marshal.h"
 #include "gedit-debug.h"
@@ -478,12 +482,14 @@ search_widget_scroll_event (GtkWidget      *widget,
 		return retval;
 
 	/* SEARCH mode */
-	if (event->direction == GDK_SCROLL_UP)
+	if ((event->state & GDK_CONTROL_MASK) &&
+	    event->direction == GDK_SCROLL_UP)
 	{
 		search_again (frame, TRUE);
 		retval = TRUE;
 	}
-	else if (event->direction == GDK_SCROLL_DOWN)
+	else if ((event->state & GDK_CONTROL_MASK) &&
+	         event->direction == GDK_SCROLL_DOWN)
 	{
 		search_again (frame, FALSE);
 		retval = TRUE;
@@ -563,10 +569,39 @@ search_widget_key_press_event (GtkWidget      *widget,
 	return retval;
 }
 
+static void
+update_search (GeditViewFrame *frame)
+{
+	if (frame->priv->search_mode == SEARCH)
+	{
+		GeditDocument *doc;
+		const gchar *entry_text;
+		gchar *search_text;
+		guint  search_flags;
+
+		doc = gedit_view_frame_get_document (frame);
+
+		entry_text = gtk_entry_get_text (GTK_ENTRY (frame->priv->search_entry));
+
+		search_text = gedit_document_get_search_text (doc, &search_flags);
+
+		if ((search_text == NULL) ||
+		    (strcmp (search_text, entry_text) != 0) ||
+		     search_flags != frame->priv->search_flags)
+		{
+			gedit_document_set_search_text (doc,
+			                                entry_text,
+			                                frame->priv->search_flags);
+		}
+
+		g_free (search_text);
+	}
+}
+
 static void
 wrap_around_menu_item_toggled (GtkCheckMenuItem *checkmenuitem,
                                GeditViewFrame   *frame)
-{	
+{
 	frame->priv->wrap_around = gtk_check_menu_item_get_active (checkmenuitem);
 }
 
@@ -576,6 +611,7 @@ match_entire_word_menu_item_toggled (GtkCheckMenuItem *checkmenuitem,
 {
 	GEDIT_SEARCH_SET_ENTIRE_WORD (frame->priv->search_flags,
 	                              gtk_check_menu_item_get_active (checkmenuitem));
+	update_search (frame);
 }
 
 static void
@@ -584,6 +620,7 @@ match_case_menu_item_toggled (GtkCheckMenuItem *checkmenuitem,
 {
 	GEDIT_SEARCH_SET_CASE_SENSITIVE (frame->priv->search_flags,
 	                                 gtk_check_menu_item_get_active (checkmenuitem));
+	update_search (frame);
 }
 
 static void
@@ -889,7 +926,6 @@ static void
 search_init (GtkWidget      *entry,
              GeditViewFrame *frame)
 {
-	GeditDocument *doc;
 	const gchar *entry_text;
 
 	/* renew the flush timeout */
@@ -902,27 +938,11 @@ search_init (GtkWidget      *entry,
 			               frame);
 	}
 
-	doc = gedit_view_frame_get_document (frame);
-
 	entry_text = gtk_entry_get_text (GTK_ENTRY (entry));
 
 	if (frame->priv->search_mode == SEARCH)
 	{
-		gchar *search_text;
-		guint  search_flags;
-
-		search_text = gedit_document_get_search_text (doc, &search_flags);
-
-		if ((search_text == NULL) ||
-		    (strcmp (search_text, entry_text) != 0) ||
-		     search_flags != frame->priv->search_flags)
-		{
-			gedit_document_set_search_text (doc,
-			                                entry_text,
-			                                frame->priv->search_flags);
-		}
-
-		g_free (search_text);
+		update_search (frame);
 
 		run_search (frame,
 		            entry_text,
@@ -941,6 +961,9 @@ search_init (GtkWidget      *entry,
 			gchar **split_text = NULL;
 			const gchar *text;
 			GtkTextIter iter;
+			GeditDocument *doc;
+
+			doc = gedit_view_frame_get_document (frame);
 
 			gtk_text_buffer_get_iter_at_mark (GTK_TEXT_BUFFER (doc),
 			                                  &iter,
@@ -1067,6 +1090,7 @@ create_search_widget (GeditViewFrame *frame)
 
 	hbox = gtk_hbox_new (FALSE, 3);
 	gtk_widget_show (hbox);
+
 	gtk_container_add (GTK_CONTAINER (search_widget), hbox);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 3);
 
@@ -1205,6 +1229,8 @@ init_search_entry (GeditViewFrame *frame)
 
 		gtk_entry_set_text (GTK_ENTRY (frame->priv->search_entry),
 		                    line_str);
+		gtk_editable_select_region (GTK_EDITABLE (frame->priv->search_entry),
+		                            0, -1);
 
 		g_free (line_str);
 
@@ -1223,24 +1249,6 @@ init_search_entry (GeditViewFrame *frame)
 
 		old_find_text = gedit_document_get_search_text (GEDIT_DOCUMENT (buffer),
 		                                                &old_find_flags);
-		if (old_find_text != NULL)
-		{
-			frame->priv->old_search_text = old_find_text;
-			add_search_completion_entry (old_find_text);
-			g_signal_handler_block (frame->priv->search_entry,
-			                        frame->priv->search_entry_changed_id);
-
-			gtk_entry_set_text (GTK_ENTRY (frame->priv->search_entry),
-			                    old_find_text);
-
-			g_signal_handler_unblock (frame->priv->search_entry,
-			                          frame->priv->search_entry_changed_id);
-		}
-		else
-		{
-			gtk_entry_set_text (GTK_ENTRY (frame->priv->search_entry),
-			                    "");
-		}
 
 		if (old_find_flags != 0)
 		{
@@ -1255,6 +1263,23 @@ init_search_entry (GeditViewFrame *frame)
 		{
 			gtk_entry_set_text (GTK_ENTRY (frame->priv->search_entry),
 			                    find_text);
+			gtk_editable_set_position (GTK_EDITABLE (frame->priv->search_entry),
+			                           -1);
+		}
+		else if (old_find_text != NULL)
+		{
+			frame->priv->old_search_text = old_find_text;
+			add_search_completion_entry (old_find_text);
+			g_signal_handler_block (frame->priv->search_entry,
+			                        frame->priv->search_entry_changed_id);
+
+			gtk_entry_set_text (GTK_ENTRY (frame->priv->search_entry),
+			                    old_find_text);
+			gtk_editable_select_region (GTK_EDITABLE (frame->priv->search_entry),
+			                            0, -1);
+
+			g_signal_handler_unblock (frame->priv->search_entry,
+			                          frame->priv->search_entry_changed_id);
 		}
 
 		g_free (find_text);
@@ -1265,10 +1290,8 @@ static void
 start_interactive_search_real (GeditViewFrame *frame)
 {
 	GtkTextBuffer *buffer;
-	GtkTextMark *mark;
 	GtkTextIter iter;
-
-	/* FIXME: it enters here twice, why? */
+	GtkTextMark *mark;
 
 	if (gtk_widget_get_visible (frame->priv->slider))
 	{
@@ -1278,6 +1301,8 @@ start_interactive_search_real (GeditViewFrame *frame)
 		}
 		else
 		{
+			gtk_editable_select_region (GTK_EDITABLE (frame->priv->search_entry),
+			                            0, -1);
 			return;
 		}
 	}
@@ -1288,14 +1313,31 @@ start_interactive_search_real (GeditViewFrame *frame)
 
 	if (frame->priv->search_mode == SEARCH)
 	{
-		mark = gtk_text_buffer_get_selection_bound (buffer);
+		GtkTextIter start, end;
+
+		if (gtk_text_buffer_get_selection_bounds (buffer, &start, &end))
+		{
+			if (gtk_text_iter_compare (&start, &end) == -1)
+			{
+				iter = start;
+			}
+			else
+			{
+				iter = end;
+			}
+		}
+		else
+		{
+			mark = gtk_text_buffer_get_selection_bound (buffer);
+			gtk_text_buffer_get_iter_at_mark (buffer, &iter, mark);
+		}
 	}
 	else
 	{
 		mark = gtk_text_buffer_get_insert (buffer);
+		gtk_text_buffer_get_iter_at_mark (buffer, &iter, mark);
 	}
 
-	gtk_text_buffer_get_iter_at_mark (buffer, &iter, mark);
 	frame->priv->start_mark = gtk_text_buffer_create_mark (buffer, NULL,
 	                                                       &iter, FALSE);
 
@@ -1304,6 +1346,20 @@ start_interactive_search_real (GeditViewFrame *frame)
 	              "animation-state", GEDIT_THEATRICS_ANIMATION_STATE_COMING,
 	              NULL);
 
+	/* NOTE: we must be very careful here to not have any text before
+	   focusing the entry because when the entry is focused the text is
+	   selected, and gtk+ doesn't allow us to have more than one selection
+	   active */
+	g_signal_handler_block (frame->priv->search_entry,
+	                        frame->priv->search_entry_changed_id);
+	gtk_entry_set_text (GTK_ENTRY (frame->priv->search_entry),
+	                    "");
+	g_signal_handler_unblock (frame->priv->search_entry,
+	                          frame->priv->search_entry_changed_id);
+
+	/* We need to grab the focus after the widget has been added */
+	gtk_widget_grab_focus (frame->priv->search_entry);
+
 	init_search_entry (frame);
 
 	/* Manage the scroll also for the view */
@@ -1316,9 +1372,6 @@ start_interactive_search_real (GeditViewFrame *frame)
 		g_timeout_add (GEDIT_VIEW_FRAME_SEARCH_DIALOG_TIMEOUT,
 		               (GSourceFunc) search_entry_flush_timeout,
 		               frame);
-
-	/* We need to grab the focus after the widget has been added */
-	gtk_widget_grab_focus (frame->priv->search_entry);
 }
 
 static void
@@ -1393,8 +1446,6 @@ gedit_view_frame_init (GeditViewFrame *frame)
 					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
 
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw),
-					     GTK_SHADOW_IN);
 	gtk_widget_show (sw);
 
 	frame->priv->overlay = gedit_animated_overlay_new (sw, frame->priv->view);
@@ -1478,7 +1529,11 @@ gedit_view_frame_clear_search (GeditViewFrame *frame)
 	doc = gedit_view_frame_get_document (frame);
 
 	gedit_document_set_search_text (doc, "", GEDIT_SEARCH_DONT_SET_FLAGS);
+	g_signal_handler_block (frame->priv->search_entry,
+	                        frame->priv->search_entry_changed_id);
 	gtk_entry_set_text (GTK_ENTRY (frame->priv->search_entry), "");
+	g_signal_handler_unblock (frame->priv->search_entry,
+	                          frame->priv->search_entry_changed_id);
 
 	gtk_widget_grab_focus (frame->priv->view);
 }
