@@ -73,16 +73,15 @@ struct _GeditViewPrivate
 	GSettings *editor_settings;
 	GtkTextBuffer *current_buffer;
 	PeasExtensionSet *extensions;
+
+	guint view_realized : 1;
 };
 
-G_DEFINE_TYPE(GeditView, gedit_view, GTK_TYPE_SOURCE_VIEW)
+G_DEFINE_TYPE(GeditView, gedit_view, GTK_SOURCE_TYPE_VIEW)
 
 /* Signals */
 enum
 {
-	START_INTERACTIVE_SEARCH,
-	START_INTERACTIVE_GOTO_LINE,
-	RESET_SEARCHED_TEXT,
 	DROP_URIS,
 	LAST_SIGNAL
 };
@@ -261,9 +260,21 @@ gedit_view_init (GeditView *view)
 static void
 gedit_view_destroy (GtkWidget *widget)
 {
-	GeditView *view;
+	GeditView *view = GEDIT_VIEW (widget);
 
-	view = GEDIT_VIEW (widget);
+	/* Disconnect notify buffer because the destroy of the textview will
+	   set the buffer to NULL, and we call get_buffer in the notify which
+	   would reinstate a GtkTextBuffer which we don't want */
+	current_buffer_removed (view);
+	g_signal_handlers_disconnect_by_func (view, on_notify_buffer_cb, NULL);
+
+	GTK_WIDGET_CLASS (gedit_view_parent_class)->destroy (widget);
+}
+
+static void
+gedit_view_dispose (GObject *object)
+{
+	GeditView *view = GEDIT_VIEW (object);
 
 	if (view->priv->extensions != NULL)
 	{
@@ -273,27 +284,19 @@ gedit_view_destroy (GtkWidget *widget)
 		view->priv->extensions = NULL;
 	}
 
-	/* Disconnect notify buffer because the destroy of the textview will
-	   set the buffer to NULL, and we call get_buffer in the notify which
-	   would reinstate a GtkTextBuffer which we don't want */
-	current_buffer_removed (view);
-	g_signal_handlers_disconnect_by_func (view, on_notify_buffer_cb, NULL);
-
 	if (view->priv->editor_settings != NULL)
 	{
 		g_object_unref (view->priv->editor_settings);
 		view->priv->editor_settings = NULL;
 	}
 
-	GTK_WIDGET_CLASS (gedit_view_parent_class)->destroy (widget);
+	G_OBJECT_CLASS (gedit_view_parent_class)->dispose (object);
 }
 
 static void
 gedit_view_finalize (GObject *object)
 {
-	GeditView *view;
-
-	view = GEDIT_VIEW (object);
+	GeditView *view = GEDIT_VIEW (object);
 
 	current_buffer_removed (view);
 
@@ -388,18 +391,6 @@ gedit_view_focus_out (GtkWidget *widget, GdkEventFocus *event)
 	return FALSE;
 }
 
-static gboolean
-reset_searched_text (GeditView *view)
-{		
-	GeditDocument *doc;
-
-	doc = GEDIT_DOCUMENT (gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)));
-	
-	gedit_document_set_search_text (doc, "", GEDIT_SEARCH_DONT_SET_FLAGS);
-	
-	return TRUE;
-}
-
 static gboolean
 gedit_view_draw (GtkWidget *widget,
                  cairo_t   *cr)
@@ -651,10 +642,14 @@ gedit_view_realize (GtkWidget *widget)
 {
 	GeditView *view = GEDIT_VIEW (widget);
 
-	/* We only activate the extensions when the view is realized,
-	 * because most plugins will expect this behaviour, and we won't
-	 * change the buffer later anyway. */
-	peas_extension_set_call (view->priv->extensions, "activate");
+	if (!view->priv->view_realized)
+	{
+		/* We only activate the extensions when the view is realized,
+		 * because most plugins will expect this behaviour, and we won't
+		 * change the buffer later anyway. */
+		peas_extension_set_call (view->priv->extensions, "activate");
+		view->priv->view_realized = TRUE;
+	}
 
 	GTK_WIDGET_CLASS (gedit_view_parent_class)->realize (widget);
 }
@@ -778,6 +773,7 @@ gedit_view_class_init (GeditViewClass *klass)
 	GtkTextViewClass *text_view_class = GTK_TEXT_VIEW_CLASS (klass);
 	GtkBindingSet    *binding_set;
 
+	object_class->dispose = gedit_view_dispose;
 	object_class->finalize = gedit_view_finalize;
 	object_class->constructed = gedit_view_constructed;
 
@@ -804,37 +800,9 @@ gedit_view_class_init (GeditViewClass *klass)
 	widget_class->drag_drop = gedit_view_drag_drop;
 	widget_class->button_press_event = gedit_view_button_press_event;
 	widget_class->realize = gedit_view_realize;
-	klass->reset_searched_text = reset_searched_text;
 
 	text_view_class->delete_from_cursor = gedit_view_delete_from_cursor;
 
-	view_signals[START_INTERACTIVE_SEARCH] =
-		g_signal_new ("start-interactive-search",
-		              G_TYPE_FROM_CLASS (object_class),
-		              G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-		              G_STRUCT_OFFSET (GeditViewClass, start_interactive_search),
-		              NULL, NULL,
-		              gedit_marshal_BOOLEAN__NONE,
-		              G_TYPE_BOOLEAN, 0);
-
-	view_signals[START_INTERACTIVE_GOTO_LINE] =
-		g_signal_new ("start-interactive-goto-line",
-		              G_TYPE_FROM_CLASS (object_class),
-		              G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-		              G_STRUCT_OFFSET (GeditViewClass, start_interactive_goto_line),
-		              NULL, NULL,
-		              gedit_marshal_BOOLEAN__NONE,
-		              G_TYPE_BOOLEAN, 0);
-
-	view_signals[RESET_SEARCHED_TEXT] =
-		g_signal_new ("reset-searched-text",
-		              G_TYPE_FROM_CLASS (object_class),
-		              G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-		              G_STRUCT_OFFSET (GeditViewClass, reset_searched_text),
-		              NULL, NULL,
-		              gedit_marshal_BOOLEAN__NONE,
-		              G_TYPE_BOOLEAN, 0);
-
 	/* A new signal DROP_URIS has been added to allow plugins to intercept
 	 * the default dnd behaviour of 'text/uri-list'. GeditView now handles
 	 * dnd in the default handlers of drag_drop, drag_motion and 
@@ -857,21 +825,6 @@ gedit_view_class_init (GeditViewClass *klass)
 
 	binding_set = gtk_binding_set_by_class (klass);
 
-	gtk_binding_entry_add_signal (binding_set,
-	                              GDK_KEY_f,
-	                              GDK_CONTROL_MASK,
-	                              "start-interactive-search", 0);
-
-	gtk_binding_entry_add_signal (binding_set,
-	                              GDK_KEY_i,
-	                              GDK_CONTROL_MASK,
-	                              "start-interactive-goto-line", 0);
-
-	gtk_binding_entry_add_signal (binding_set,
-	                              GDK_KEY_k,
-	                              GDK_CONTROL_MASK | GDK_SHIFT_MASK,
-	                              "reset_searched_text", 0);
-
 	gtk_binding_entry_add_signal (binding_set,
 	                              GDK_KEY_d,
 	                              GDK_CONTROL_MASK,
