@@ -340,28 +340,16 @@ restore_default_location (GeditFileBrowserPlugin *plugin)
 	g_free (virtual_root);
 }
 
-static GeditFileBrowserViewClickPolicy
-click_policy_from_string (gchar const *click_policy)
-{
-	if (click_policy && strcmp (click_policy, "single") == 0)
-		return GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_SINGLE;
-	else
-		return GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_DOUBLE;
-}
-
 static void
 on_click_policy_changed (GSettings              *settings,
 			 const gchar            *key,
 			 GeditFileBrowserPlugin *plugin)
 {
 	GeditFileBrowserPluginPrivate *priv = plugin->priv;
-	gchar *click_policy;
-	GeditFileBrowserViewClickPolicy policy = GEDIT_FILE_BROWSER_VIEW_CLICK_POLICY_DOUBLE;
+	GeditFileBrowserViewClickPolicy policy;
 	GeditFileBrowserView *view;
 
-	click_policy = g_settings_get_string (settings, key);
-	policy = click_policy_from_string (click_policy);
-	g_free (click_policy);
+	policy = g_settings_get_enum (settings, key);
 
 	view = gedit_file_browser_widget_get_browser_view (priv->tree_widget);
 	gedit_file_browser_view_set_click_policy (view, policy);
@@ -379,29 +367,22 @@ static void
 install_nautilus_prefs (GeditFileBrowserPlugin *plugin)
 {
 	GeditFileBrowserPluginPrivate *priv = plugin->priv;
-	gchar *pref;
 	gboolean prefb;
 	GeditFileBrowserViewClickPolicy policy;
 	GeditFileBrowserView *view;
 
 	/* Get click_policy */
-	pref = g_settings_get_string (priv->nautilus_settings,
+	policy = g_settings_get_enum (priv->nautilus_settings,
 				      NAUTILUS_CLICK_POLICY_KEY);
 
-	policy = click_policy_from_string (pref);
-
 	view = gedit_file_browser_widget_get_browser_view (priv->tree_widget);
 	gedit_file_browser_view_set_click_policy (view, policy);
 
-	if (pref)
-	{
-		priv->click_policy_handle =
-			g_signal_connect (priv->nautilus_settings,
-					  "changed::" NAUTILUS_CLICK_POLICY_KEY,
-					  G_CALLBACK (on_click_policy_changed),
-					  plugin);
-		g_free (pref);
-	}
+	priv->click_policy_handle =
+		g_signal_connect (priv->nautilus_settings,
+				  "changed::" NAUTILUS_CLICK_POLICY_KEY,
+				  G_CALLBACK (on_click_policy_changed),
+				  plugin);
 
 	/* Bind enable-delete */
 	g_settings_bind (priv->nautilus_settings,
@@ -487,9 +468,6 @@ on_action_open_terminal (GtkAction              *action,
                          GeditFileBrowserPlugin *plugin)
 {
 	GeditFileBrowserPluginPrivate *priv = plugin->priv;
-	gchar *terminal;
-	gchar *local;
-	gchar *argv[2];
 	GFile *file;
 
 	GtkTreeIter iter;
@@ -506,27 +484,32 @@ on_action_open_terminal (GtkAction              *action,
 	                    &file,
 	                    -1);
 
-	if (file == NULL)
-		return;
+	if (file)
+	{
+		gchar *terminal;
+		gchar *local;
+		gchar *argv[2];
 
-	terminal = get_terminal (plugin);
+		terminal = get_terminal (plugin);
 
-	local = g_file_get_path (file);
+		local = g_file_get_path (file);
 
-	argv[0] = terminal;
-	argv[1] = NULL;
+		argv[0] = terminal;
+		argv[1] = NULL;
 
-	g_spawn_async (local,
-	               argv,
-	               NULL,
-	               G_SPAWN_SEARCH_PATH,
-	               NULL,
-	               NULL,
-	               NULL,
-	               NULL);
+		g_spawn_async (local,
+			       argv,
+			       NULL,
+			       G_SPAWN_SEARCH_PATH,
+			       NULL,
+			       NULL,
+			       NULL,
+			       NULL);
 
-	g_free (terminal);
-	g_free (local);
+		g_free (terminal);
+		g_free (local);
+		g_object_unref (file);
+	}
 }
 
 static void
@@ -538,7 +521,6 @@ on_selection_changed_cb (GtkTreeSelection       *selection,
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	gboolean sensitive;
-	GFile *location;
 
 	tree_view = GTK_TREE_VIEW (gedit_file_browser_widget_get_browser_view (priv->tree_widget));
 	model = gtk_tree_view_get_model (tree_view);
@@ -550,11 +532,21 @@ on_selection_changed_cb (GtkTreeSelection       *selection,
 
 	if (sensitive)
 	{
+		GFile *location;
+
 		gtk_tree_model_get (model, &iter,
 				    GEDIT_FILE_BROWSER_STORE_COLUMN_LOCATION,
 				    &location, -1);
 
-		sensitive = gedit_utils_location_has_file_scheme (location);
+		if (location)
+		{
+			sensitive = gedit_utils_location_has_file_scheme (location);
+			g_object_unref (location);
+		}
+		else
+		{
+			sensitive = FALSE;
+		}
 	}
 
 	gtk_action_set_sensitive (
@@ -1083,13 +1075,20 @@ get_filename_from_path (GtkTreeModel *model,
 {
 	GtkTreeIter iter;
 	GFile *location;
+	gchar *ret = NULL;
 
 	gtk_tree_model_get_iter (model, &iter, path);
 	gtk_tree_model_get (model, &iter,
 			    GEDIT_FILE_BROWSER_STORE_COLUMN_LOCATION, &location,
 			    -1);
 
-	return gedit_file_browser_utils_file_basename (location);
+	if (location)
+	{
+		ret = gedit_file_browser_utils_file_basename (location);
+		g_object_unref (location);
+	}
+
+	return ret;
 }
 
 static gboolean
