@@ -1,19 +1,19 @@
 /*
- * gedit-file-browser-widget.h - Gedit plugin providing easy file access 
+ * gedit-file-browser-widget.h - Gedit plugin providing easy file access
  * from the sidepanel
- * 
+ *
  * Copyright (C) 2006 - Jesse van den Kieboom <jesse@icecrew.nl>
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
@@ -46,14 +46,14 @@ gboolean (*GeditFileBrowserWidgetFilterFunc) (GeditFileBrowserWidget *obj,
 					      GtkTreeIter            *iter,
 					      gpointer                user_data);
 
-struct _GeditFileBrowserWidget 
+struct _GeditFileBrowserWidget
 {
 	GtkVBox parent;
 
 	GeditFileBrowserWidgetPrivate *priv;
 };
 
-struct _GeditFileBrowserWidgetClass 
+struct _GeditFileBrowserWidgetClass
 {
 	GtkVBoxClass parent_class;
 
@@ -71,7 +71,6 @@ struct _GeditFileBrowserWidgetClass
 };
 
 GType		 gedit_file_browser_widget_get_type            (void) G_GNUC_CONST;
-GType		 gedit_file_browser_widget_register_type       (GTypeModule             *module);
 
 GtkWidget	*gedit_file_browser_widget_new            	(const gchar            *data_dir);
 
@@ -115,6 +114,8 @@ void		 gedit_file_browser_widget_refresh		(GeditFileBrowserWidget *obj);
 void		 gedit_file_browser_widget_history_back		(GeditFileBrowserWidget *obj);
 void		 gedit_file_browser_widget_history_forward	(GeditFileBrowserWidget *obj);
 
+void		 _gedit_file_browser_widget_register_type      (GTypeModule            *type_module);
+
 G_END_DECLS
 
 #endif /* __GEDIT_FILE_BROWSER_WIDGET_H__ */
