@@ -79,7 +79,10 @@ has_option (ModelineOptions *options,
 void
 modeline_parser_init (const gchar *data_dir)
 {
-	modelines_data_dir = g_strdup (data_dir);
+	if (modelines_data_dir == NULL)
+	{
+		modelines_data_dir = g_strdup (data_dir);
+	}
 }
 
 void
@@ -99,6 +102,7 @@ modeline_parser_shutdown ()
 	kate_languages = NULL;
 
 	g_free (modelines_data_dir);
+	modelines_data_dir = NULL;
 }
 
 static GHashTable *
@@ -786,7 +790,7 @@ modeline_parser_apply_modeline (GtkSourceView *view)
 	{
 		guint tab_width;
 		
-		g_settings_get (settings, "u", GEDIT_SETTINGS_TABS_SIZE, &tab_width);
+		g_settings_get (settings, GEDIT_SETTINGS_TABS_SIZE, "u", &tab_width);
 	
 		gtk_source_view_set_tab_width (view, tab_width);
 	}
@@ -821,7 +825,7 @@ modeline_parser_apply_modeline (GtkSourceView *view)
 	{
 		guint right_margin_pos;
 		
-		g_settings_get (settings, "u", GEDIT_SETTINGS_RIGHT_MARGIN_POSITION,
+		g_settings_get (settings, GEDIT_SETTINGS_RIGHT_MARGIN_POSITION, "u",
 				&right_margin_pos);
 		gtk_source_view_set_right_margin_position (view, 
 		                                           right_margin_pos);
@@ -842,6 +846,7 @@ modeline_parser_apply_modeline (GtkSourceView *view)
 	
 	if (previous)
 	{
+		g_free (previous->language_id);
 		*previous = options;
 		previous->language_id = g_strdup (options.language_id);
 	}
